﻿/*==============================================================*/
/* Table: O2P_T_OBJECT                                          */
/*==============================================================*/
CREATE TABLE ORA2PG_PROJECT.O2P_T_OBJECT (
   ID                   ORA2PG_PROJECT.O2P_D_ID             NOT NULL,
   ACSESSION4O_ID       ORA2PG_PROJECT.O2P_D_ID             NULL,
   POSTGRES_SCHEMA      ORA2PG_PROJECT.O2P_D_NAME           NULL,
   NAME                 ORA2PG_PROJECT.O2P_D_NAME           NOT NULL,
   STEP4O_ID            ORA2PG_PROJECT.O2P_D_ID             NULL,
   NUM                  ORA2PG_PROJECT.O2P_D_INTPOS         NULL,
   USERNAME             ORA2PG_PROJECT.O2P_D_USERNAME       NULL,
   OSTATUS4O_CODE       ORA2PG_PROJECT.O2P_D_CODE32         NOT NULL,
   PGTYPE4O_CODE        ORA2PG_PROJECT.O2P_D_CODE32         NOT NULL,
   O4O_ID               ORA2PG_PROJECT.O2P_D_ID             NULL,
   DESCRIPTION          ORA2PG_PROJECT.O2P_D_DESCRIPTION    NULL,
   END_CAUSE            ORA2PG_PROJECT.O2P_D_NOTES          NULL,
   POSTGRES_SCRIPT      ORA2PG_PROJECT.O2P_D_SCRIPT         NULL,
   PG_LOG               ORA2PG_PROJECT.O2P_D_LOG            NULL,
   PGSCRIPT_ID          ORA2PG_PROJECT.O2P_D_ID             NULL,
   PROJECT4O_CODE       ORA2PG_PROJECT.O2P_D_CODE32         NOT NULL,
   TASK2MEMBER          ORA2PG_PROJECT.O2P_D_DESCRIPTION    NULL,
   SERVER_CODE          ORA2PG_PROJECT.O2P_D_CODE32         NULL,
   FILEPATH             ORA2PG_PROJECT.O2P_D_TEXT           NULL,
   FILE4O_ID            ORA2PG_PROJECT.O2P_D_ID             NULL,
   DST_TAB_NAME         ORA2PG_PROJECT.O2P_D_NAME           NULL,
   CONSTRAINT O2P_T_OBJECT_NUM_UK UNIQUE (STEP4O_ID, NUM)
   USING INDEX TABLESPACE ORA2PG_PROJECT
)
WITHOUT OIDS
TABLESPACE ORA2PG_PROJECT;

COMMENT ON TABLE ORA2PG_PROJECT.O2P_T_OBJECT IS 'Объект Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.ID IS 'ID объекта Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.ACSESSION4O_ID IS 'ID сессии автомиграции';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.POSTGRES_SCHEMA IS 'Имя схемы, в которой должен создаваться объект Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.NAME IS 'Наименование объекта Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.STEP4O_ID IS 'ID этапа миграции';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.NUM IS 'Порядковый номер применения скрипта в БД Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.USERNAME IS 'Имя пользователя, ответственного за миграцию объекта';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.OSTATUS4O_CODE IS 'Код состояния объекта Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.PGTYPE4O_CODE IS 'Код типа объектов в Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.O4O_ID IS 'ID объекта Postgres, полученного при автомиграции, на основании которого создан данный объект';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.DESCRIPTION IS 'Описание особенностей применения скрипта объекта Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.END_CAUSE IS 'Причина завершения работы на объектом Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.POSTGRES_SCRIPT IS 'Скрипт создания объекта в БД Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.PG_LOG IS 'Журнал применения скрипта для Posgres в БД Postgres';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.PGSCRIPT_ID IS 'ID скрипта';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.PROJECT4O_CODE IS 'Код проекта';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.TASK2MEMBER IS 'Задание ответственному';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.SERVER_CODE IS 'Код сервера';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.FILEPATH IS 'Путь к файлу, которым является объект';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.FILE4O_ID IS 'ID файла, содержащего скрипт добавления данных в postgres-объект (таблицу)';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_OBJECT.DST_TAB_NAME IS 'Имя таблицы в Postgres, если объект является таблицей';

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_OBJECT_PK PRIMARY KEY (ID)
   USING INDEX TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_OBJECT_OSTATUS4O_FK                             */
/*==============================================================*/
CREATE  INDEX O2P_T_OBJECT_OSTATUS4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT USING BTREE (
OSTATUS4O_CODE
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_OBJECT_STEP4O_FK                                */
/*==============================================================*/
CREATE  INDEX O2P_T_OBJECT_STEP4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT USING BTREE (
STEP4O_ID
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_OBJECT_USERNAME_FK                              */
/*==============================================================*/
CREATE  INDEX O2P_T_OBJECT_USERNAME_FK ON ORA2PG_PROJECT.O2P_T_OBJECT USING BTREE (
USERNAME
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_ASCESSION4O_FK                                  */
/*==============================================================*/
CREATE  INDEX O2P_T_ASCESSION4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT (
ACSESSION4O_ID
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_PGTYPE4O_FK                                     */
/*==============================================================*/
CREATE  INDEX O2P_T_PGTYPE4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT (
PGTYPE4O_CODE
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_O4O_FK                                          */
/*==============================================================*/
CREATE  INDEX O2P_T_O4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT (
O4O_ID
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_LTEXT4O_FK                                      */
/*==============================================================*/
CREATE  INDEX O2P_T_LTEXT4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT (
PGSCRIPT_ID
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_PROJECT4O_FK                                    */
/*==============================================================*/
CREATE  INDEX O2P_T_PROJECT4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT (
PROJECT4O_CODE
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_SERVER4O_FK                                     */
/*==============================================================*/
CREATE  INDEX O2P_T_SERVER4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT (
SERVER_CODE
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_FILE4O_FK                                       */
/*==============================================================*/
CREATE  INDEX O2P_T_FILE4O_FK ON ORA2PG_PROJECT.O2P_T_OBJECT (
FILE4O_ID
) TABLESPACE ORA2PG_PROJECT;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_ASCESSION4O_FK FOREIGN KEY (ACSESSION4O_ID)
      REFERENCES ORA2PG_PROJECT.O2P_T_ACSESSION (ID)
      ON DELETE CASCADE ON UPDATE RESTRICT;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_FILE4O_FK FOREIGN KEY (FILE4O_ID)
      REFERENCES ORA2PG_PROJECT.O2P_T_FILE (ID)
      ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_LTEXT4O_FK FOREIGN KEY (PGSCRIPT_ID)
      REFERENCES ORA2PG_PROJECT.O2P_T_LONG_TEXT (ID)
      ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_O4O_FK FOREIGN KEY (O4O_ID)
      REFERENCES ORA2PG_PROJECT.O2P_T_OBJECT (ID)
      ON DELETE SET NULL ON UPDATE RESTRICT;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_OBJECT_OSTATUS4O_FK FOREIGN KEY (OSTATUS4O_CODE)
      REFERENCES ORA2PG_PROJECT.O2P_T_RF_OBJECT_STATUS (CODE)
      ON DELETE RESTRICT ON UPDATE CASCADE;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_OBJECT_STEP4O_FK FOREIGN KEY (STEP4O_ID)
      REFERENCES ORA2PG_PROJECT.O2P_T_STEP (ID)
      ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_OBJECT_USERNNAME_FK FOREIGN KEY (USERNAME)
      REFERENCES ORA2PG_PROJECT.O2P_T_USER (USERNAME)
      ON DELETE SET NULL ON UPDATE CASCADE;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_PGTYPE4O_FK FOREIGN KEY (PGTYPE4O_CODE)
      REFERENCES ORA2PG_PROJECT.O2P_T_RF_POSTGRES_TYPE (CODE)
      ON DELETE RESTRICT ON UPDATE CASCADE;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_PROJECT4O_FK FOREIGN KEY (PROJECT4O_CODE)
      REFERENCES ORA2PG_PROJECT.O2P_T_PROJECT (CODE)
      ON DELETE CASCADE ON UPDATE CASCADE;

ALTER TABLE ORA2PG_PROJECT.O2P_T_OBJECT
   ADD CONSTRAINT O2P_T_SERVER4O_FK FOREIGN KEY (SERVER_CODE)
      REFERENCES ORA2PG_PROJECT.O2P_T_RF_SERVER (CODE)
      ON DELETE RESTRICT ON UPDATE CASCADE;
