﻿/*==============================================================*/
/* Table: O2P_T_PROJECT_OBJECT                                  */
/*==============================================================*/
CREATE TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT (
   ID                   ORA2PG_PROJECT.O2P_D_ID             NOT NULL,
   NAME                 ORA2PG_PROJECT.O2P_D_NAME           NULL,
   EXPORT_SCHEMA        ORA2PG_PROJECT.O2P_D_CODE32         NULL,
   NOTES                ORA2PG_PROJECT.O2P_D_NOTES          NULL,
   MOTYPE_CODE          ORA2PG_PROJECT.O2P_D_CODE32         NOT NULL,
   PROJECT4OBJ_CODE     ORA2PG_PROJECT.O2P_D_CODE32         NOT NULL,
   PO4PO_ID             ORA2PG_PROJECT.O2P_D_ID             NULL,
   COMMENT              ORA2PG_PROJECT.O2P_D_DESCRIPTION    NULL,
   ORACLE_SCRIPT        ORA2PG_PROJECT.O2P_D_SCRIPT         NULL,
   DST_TAB_NAME         ORA2PG_PROJECT.O2P_D_NAME           NULL,
   WHERE_CLAUSE         ORA2PG_PROJECT.O2P_D_TEXT           NULL,
   ORASCRIPT_MODIFIED   ORA2PG_PROJECT.O2P_D_NY             NULL,
   POSTATUS4PO_CODE     ORA2PG_PROJECT.O2P_D_CODE32         NOT NULL DEFAULT 'NEW',
   USERNAME             ORA2PG_PROJECT.O2P_D_USERNAME       NULL,
   TASK2MEMBER          ORA2PG_PROJECT.O2P_D_TEXT           NULL,
   ORADDL4PO_ID         ORA2PG_PROJECT.O2P_D_ID             NULL,
   CONVERSION_REQUIRED  ORA2PG_PROJECT.O2P_D_NY             NULL,
   SERVER_CODE          ORA2PG_PROJECT.O2P_D_CODE32         NULL,
   FILEPATH             ORA2PG_PROJECT.O2P_D_TEXT           NULL
)
WITHOUT OIDS
TABLESPACE ORA2PG_PROJECT;

COMMENT ON TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT IS 'Объект проекта миграции';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.ID IS 'ID объекта проекта';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.NAME IS 'Наименование объекта проекта';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.EXPORT_SCHEMA IS 'Схема Oracle, из которой должен экспортироваться объект';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.NOTES IS 'Примечания к объекту проекта миграции';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.MOTYPE_CODE IS 'Код типа объектов миграции';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.PROJECT4OBJ_CODE IS 'Код проекта миграции';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.PO4PO_ID IS 'ID объекта проекта - таблицы для индекса, констрейнта или внешнего ключа';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.COMMENT IS 'Комментарий к объекту в БД Oracle';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.ORACLE_SCRIPT IS 'Скрипт создания объекта в БД Oracle';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.DST_TAB_NAME IS 'Новое имя таблицы в Postgres, если объект проекта является таблицей';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.WHERE_CLAUSE IS 'Ограничение миграции данных из таблицы';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.ORASCRIPT_MODIFIED IS 'Изменён ли вручную пользователем скрипт создания объекта в БД Oracle';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.POSTATUS4PO_CODE IS 'Код состояния объекта проекта';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.USERNAME IS 'Ответственный за подготовку объекта к автомиграции';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.TASK2MEMBER IS 'Задание ответственному';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.ORADDL4PO_ID IS 'ID DDL-скрипта, принятого в работу';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.CONVERSION_REQUIRED IS 'Требуется повторная конвертация/миграция объекта проекта';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.SERVER_CODE IS 'Код сервера';

COMMENT ON COLUMN ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT.FILEPATH IS 'Путь к файлу, которым является объект проекта';

ALTER TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT
   ADD CONSTRAINT O2P_T_PROJECT_OBJECT_PK PRIMARY KEY (ID)
   USING INDEX TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_PROJECT_OBJECT_MOTYPE_FK                        */
/*==============================================================*/
CREATE  INDEX O2P_T_PROJECT_OBJECT_MOTYPE_FK ON ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT USING BTREE (
MOTYPE_CODE
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_PROJECT_OBJECT_PROJECT4OB                       */
/*==============================================================*/
CREATE  INDEX O2P_T_PROJECT_OBJECT_PROJECT4OB ON ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT USING BTREE (
PROJECT4OBJ_CODE
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_PO4PO_FK                                        */
/*==============================================================*/
CREATE  INDEX O2P_T_PO4PO_FK ON ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT (
PO4PO_ID
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_POSTATUS4PO_FK                                  */
/*==============================================================*/
CREATE  INDEX O2P_T_POSTATUS4PO_FK ON ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT (
POSTATUS4PO_CODE
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_USERNAME4PO_FK                                  */
/*==============================================================*/
CREATE  INDEX O2P_T_USERNAME4PO_FK ON ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT (
USERNAME
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_ORADDL4PO_FK                                    */
/*==============================================================*/
CREATE  INDEX O2P_T_ORADDL4PO_FK ON ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT (
ORADDL4PO_ID
) TABLESPACE ORA2PG_PROJECT;

/*==============================================================*/
/* Index: O2P_T_SERVER4PO_FK                                    */
/*==============================================================*/
CREATE  INDEX O2P_T_SERVER4PO_FK ON ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT (
SERVER_CODE
) TABLESPACE ORA2PG_PROJECT;


ALTER TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT
   ADD CONSTRAINT O2P_T_PO4PO_FK FOREIGN KEY (PO4PO_ID)
      REFERENCES ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT (ID)
      ON DELETE CASCADE ON UPDATE RESTRICT;

ALTER TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT
   ADD CONSTRAINT O2P_T_POSTATUS4PO_FK FOREIGN KEY (POSTATUS4PO_CODE)
      REFERENCES ORA2PG_PROJECT.O2P_T_RF_POBJECT_STATUS (CODE)
      ON DELETE RESTRICT ON UPDATE CASCADE;

ALTER TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT
   ADD CONSTRAINT O2P_T_PROJECT_OBJECT_MOTYPE_FK FOREIGN KEY (MOTYPE_CODE)
      REFERENCES ORA2PG_PROJECT.O2P_T_RF_OBJECT_TYPE (CODE)
      ON DELETE RESTRICT ON UPDATE CASCADE;

ALTER TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT
   ADD CONSTRAINT O2P_T_PROJECT_OBJECT_PROJECT4OBJ_FK FOREIGN KEY (PROJECT4OBJ_CODE)
      REFERENCES ORA2PG_PROJECT.O2P_T_PROJECT (CODE)
      ON DELETE RESTRICT ON UPDATE CASCADE;

ALTER TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT
   ADD CONSTRAINT O2P_T_SERVER4PO_FK FOREIGN KEY (SERVER_CODE)
      REFERENCES ORA2PG_PROJECT.O2P_T_RF_SERVER (CODE)
      ON DELETE RESTRICT ON UPDATE CASCADE;

ALTER TABLE ORA2PG_PROJECT.O2P_T_PROJECT_OBJECT
   ADD CONSTRAINT O2P_T_USERNAME4PO_FK FOREIGN KEY (USERNAME)
      REFERENCES ORA2PG_PROJECT.O2P_T_USER (USERNAME)
      ON DELETE RESTRICT ON UPDATE CASCADE;
