CREATE OR REPLACE FUNCTION ora2pg_project.o2p_f_make_command (
  p_project_code text,
  p_acsession_id numeric,
  p_stage_name text,
  p_oracle_home text
)
RETURNS text AS
$body$
DECLARE
 r record;
 o record;
 p record;
 cmd text;
 pname text;
 oschema text;
 reponly text;
 i numeric;
 p1 integer;
 p2 integer;
 p3 integer;
 str text;
begin
 if p_stage_name='CREATE_DIR' then
  return
  'HOST:O2P_H_INIT_PROJECT;P_PROJECT_CODE:'||P_PROJECT_CODE||chr(10)||
  ''||chr(10)||
  'P_ORACLE_HOME='||replace(coalesce(P_ORACLE_HOME,''),chr(13),'');
 --
 elsif p_stage_name='MAKE_ORACLE_HOME_SCRIPT' then
  return
  'Property2File:{Property:FormID}.P_ORACLE_HOME.Value;Filename:{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/export_schema.sh;LineSeparator:null;';
 --
 elsif p_stage_name='EXECUTE_ORACLE_HOME_SCRIPT' then
  return
  'HOST:O2P_H_CONVERT;P_PROJECT_CODE:'||P_PROJECT_CODE||';';
 --
 elsif p_stage_name='GET_ORACLE_HOME' then
  return
  'FormProperty:OracleHome='||chr(10)||
  ''||chr(10)||
  'File2Property:{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/oracle_home.lst;Property:{Property:FormID}.Form.OracleHome;';
 --
 elsif p_stage_name='SET_ORACLE_HOME_PARAM' then
  return
  'JS:App.forms.get("{Property:FormID}").elements.get("P_ORA2PG_CONFIG").setProperty("Value",'||
  'App.forms.get("{Property:FormID}").elements.get("P_ORA2PG_CONFIG").getProperty("Value").replace("ORACLE_HOME 1",'||
  '"ORACLE_HOME {FormProperty:OracleHome}"))';
 --
 elsif p_stage_name='DEBUG' then
-- return ' ';
  return
  'F:P_ORA2PG_CONFIG={F:P_ORA2PG_CONFIG}';
 --
 elsif p_stage_name='SET_CONFIG' then
  return
  'Property2File:{Property:FormID}.P_ORA2PG_CONFIG.Value;Filename:{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/config/ora2pg.conf;LineSeparator:null;';
 --
 elsif p_stage_name='MAKE_EXPORT_SCHEMA_SCRIPT' then
  return
  'Property2File:{Property:FormID}.P_ORA2PG_EXPORT.Value;Filename:{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/export_schema.sh;LineSeparator:null;';
 --
 elsif p_stage_name='MAKE_SOURCES_SCRIPTS' then
   select report_only into reponly from o2p_t_acsession where id=P_ACSESSION_ID;
   if reponly='Y' then return null; end if;
   select oschema4acsession_name into oschema from o2p_t_acsession where id=P_ACSESSION_ID;
   cmd := '';
   for r in 
       (select po.* 
	      from o2p_t_acsession_ot acot 
          join o2p_t_project_object po on po.motype_code = acot.ot_code
         where acot.acsession4acot_id = p_acsession_id
           and po.project4obj_code = p_project_code 
           and po.export_schema = oschema
           and po.orascript_modified = 'Y'
		   and po.motype_code in ('FUNCTION','MVIEW','PACKAGE','PARTITION','PROCEDURE','TRIGGER','TYPE','VIEW'))
   loop
     if cmd > ' ' then cmd := cmd||chr(10)||chr(10); end if;
	 cmd := cmd||'Lob2File:select oracle_script from o2p_t_project_object where id='||r.id||
	        ';File:{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/sources/'||lower(r.motype_code)||'s/'||r.name||'.sql;';
   end loop;
   return cmd;
 --
 elsif p_stage_name='CONVERT' then
  return
  'HOST:O2P_H_CONVERT;P_PROJECT_CODE:'||P_PROJECT_CODE||';';
 --
 elsif p_stage_name='GET_CONVERT_RESULT_FILE' then
  return 'File2Lob:{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/export_schema.log;SQL:update o2p_t_acsession set errtext=convert_from(?,''UTF8'') where id='||p_acsession_id||';'||chr(10)||
  chr(10)||
  'SQL:commit;';
 --
 elsif p_stage_name='CHECK_CONVERT_RESULT' then
  if o2p_f_isconvertok(p_acsession_id::o2p_d_id)='ERROR' then
    return 'ShowMessage:O2P-00015;';
  else
    --   .   conversion_required      p_acsession_id  
    return
	'PLPGSQL:declare rec record;
    porec record;
begin
  for rec in 
      (select ac.project4acsession_code, 
	          ac.oschema4acsession_name, 
			  ot.ot_code
	     from o2p_t_acsession ac
		 join o2p_t_acsession_ot ot on ot.acsession4acot_id = ac.id
	    where ac.id = '||coalesce(p_acsession_id,0)||')
  loop
    for porec in (select id from o2p_t_project_object
      where project4obj_code = rec.project4acsession_code
	   and coalesce(export_schema,''!'') = coalesce(rec.oschema4acsession_name,''!'')
	   and motype_code = rec.ot_code
	   and o2p_f_is_conversion_required(id) = ''Y'') loop
      --     
      update o2p_t_project_object 
	    set conversion_required = ''N''
	  where id=porec.id and conversion_required = ''Y'';
      --     
      update o2p_t_project_object
        set conversion_required = ''N''
      where po4po_id=porec.id and conversion_required = ''Y'';
    end loop;
  end loop;
end;'||chr(10)||chr(10)||'SQL:commit;';
  end if;
 --
 elsif p_stage_name='GET_REPORT' then
  select report_only into reponly from o2p_t_acsession where id=P_ACSESSION_ID;
  if reponly='Y' then
   return
   'FormProperty:PropertyFromFile='||chr(10)||
   chr(10)||
   'File2Property:{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/reports/report.html;Property:{Property:FormID}.Form.PropertyFromFile;';
  else
   return null;
  end if;
 --
 elsif p_stage_name='SET_REPORT' then
  select report_only into reponly from o2p_t_acsession where id=P_ACSESSION_ID;
  if reponly='Y' then
   return
   'JS:App.forms.get("{Property:FormID}").elements.get("P_REPORT").setProperty("Value",App.forms.get("{Property:FormID}").getProperty("PropertyFromFile"))';
  else
   return null;
  end if;
 --
 elsif p_stage_name='SAVE_REPORT' then
  select report_only into reponly from o2p_t_acsession where id=P_ACSESSION_ID;
  if reponly='Y' then
   return
   'SQL:update o2p_t_acsession set result={F2SQL:P_REPORT} where id='||P_ACSESSION_ID||';commit;';
  else
   return null;
  end if;
 --
 elsif p_stage_name='GET_FILES' then
  select report_only into reponly from o2p_t_acsession where id=P_ACSESSION_ID;
  if reponly='Y' then return null; end if;
  for r in (select * from o2p_t_acsession_ot where acsession4acot_id=P_ACSESSION_ID) loop
   cmd := coalesce(cmd,'')||chr(10)||
   ''||chr(10)||
   'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id)'||chr(10)||
   'values(nextval(''o2p_q_file''),'''||
   case
   when r.ot_code='DIRECTORY' then 'directorie'
   when r.ot_code='USER' then 'grant'
   when r.ot_code='ROLE' then 'grant'
   else lower(r.ot_code)
   end||'.sql'','||chr(10)||
   '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||
   case
   when r.ot_code='DIRECTORY' then 'directorie'
   when r.ot_code='USER' then 'grant'
   when r.ot_code='ROLE' then 'grant'
   else lower(r.ot_code)
   end||'s'','||chr(10)||
   '''-'','||r.id||');commit;';
   --
   if lower(r.ot_code)='table' then
    cmd := cmd||chr(10)||
    ''||chr(10)||
    'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
    'values(nextval(''o2p_q_file''),''INDEXES_'||lower(r.ot_code)||'.sql'','||chr(10)||
    '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
    '''-'','||r.id||',2);commit;'||chr(10)||
    ''||chr(10)||
    'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
    'values(nextval(''o2p_q_file''),''FKEYS_'||lower(r.ot_code)||'.sql'','||chr(10)||
    '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
    '''-'','||r.id||',4);commit;'||chr(10)||
    ''||chr(10)||
    'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
    'values(nextval(''o2p_q_file''),''CONSTRAINTS_'||lower(r.ot_code)||'.sql'','||chr(10)||
    '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
    '''-'','||r.id||',3);commit;';
   --
   elsif lower(r.ot_code)='mview' then
    i := 1;
    for o in (select name from o2p_t_project_object where project4obj_code=P_PROJECT_CODE and motype_code=r.ot_code order by name) loop
     i := i+1;
     cmd := coalesce(cmd,'')||chr(10)||
     ''||chr(10)||
      'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
      'values(nextval(''o2p_q_file''),'''||o.name||'_'||lower(r.ot_code)||'.sql'','||chr(10)||
      '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
      '''-'','||r.id||','||i||');commit;';
    end loop;
   --
   elsif lower(r.ot_code)='view' then
    i := 1;
    for o in (select name from o2p_t_project_object where project4obj_code=P_PROJECT_CODE and motype_code=r.ot_code order by name) loop
     i := i+1;
     cmd := coalesce(cmd,'')||chr(10)||
     ''||chr(10)||
      'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
      'values(nextval(''o2p_q_file''),'''||o.name||'_'||lower(r.ot_code)||'.sql'','||chr(10)||
      '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
      '''-'','||r.id||','||i||');commit;';
    end loop;
   --
   elsif lower(r.ot_code)='tablespace' then
    cmd := cmd||chr(10)||
    ''||chr(10)||
    'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
    'values(nextval(''o2p_q_file''),''TBSP_INDEXES_'||lower(r.ot_code)||'.sql'','||chr(10)||
    '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
    '''-'','||r.id||',2);commit;';
   --
   elsif lower(r.ot_code) in ('procedure','function') then
    i := 1;
    for o in (select name from o2p_t_project_object where project4obj_code=P_PROJECT_CODE and motype_code=r.ot_code order by name) loop
     i := i+1;
     cmd := coalesce(cmd,'')||chr(10)||
     ''||chr(10)||
      'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
      'values(nextval(''o2p_q_file''),'''||o.name||'_'||lower(r.ot_code)||'.sql'','||chr(10)||
      '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
      '''-'','||r.id||','||i||');commit;';
    end loop;
   --
   elsif lower(r.ot_code)='trigger' then
    i := 1;
    for o in (select name from o2p_t_project_object where project4obj_code=P_PROJECT_CODE and motype_code=r.ot_code order by name) loop
     i := i+1;
     cmd := coalesce(cmd,'')||chr(10)||
     ''||chr(10)||
      'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
      'values(nextval(''o2p_q_file''),'''||o.name||'_'||lower(r.ot_code)||'.sql'','||chr(10)||
      '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
      '''-'','||r.id||','||i||');commit;';
    end loop;
   elsif lower(r.ot_code)='package' then
    cmd := coalesce(cmd,'')||chr(10)||
    ''||chr(10)||
    'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
    'values(nextval(''o2p_q_file''),''global_variables.conf'','||chr(10)||
    '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||'/schema/'||lower(r.ot_code)||'s'','||chr(10)||
    '''-'','||r.id||',2);commit;';
    i := 1;
    for o in
     (select name,oracle_script from o2p_t_project_object
      where project4obj_code=P_PROJECT_CODE and motype_code=r.ot_code order by name
     )
    loop
     --   
     select value into o.oracle_script from o2p_f_l2t(lower(o.oracle_script),'body') where num=2;
     --  
     loop
       exit when coalesce(o.oracle_script,'')='';
       p2 := position('*/' in o.oracle_script);
       exit when p2=0;
       str :=substring(o.oracle_script from 1 for (p2+1)::integer);
       p1 := position('*/' in reverse(str));
       if p1=0 then --   
         o.oracle_script := substring(o.oracle_script from 1 for p2-1)||'*`/'||substring(o.oracle_script from p2+2);
         continue;
       end if;
       str :=substring(str from (length(str)-p1)::integer);
       o.oracle_script := replace(o.oracle_script,str,'');
     end loop;
     o.oracle_script := replace(o.oracle_script,'*`/','*/');
     --
     --   
     loop
       exit when coalesce(o.oracle_script,'')='';
       p1 := position('''' in o.oracle_script);
       exit when p1=0;
       str :=substring(o.oracle_script from p1+1);
       o.oracle_script := substring(o.oracle_script from 1 for p1-1)||'~'||substring(o.oracle_script from p1+1);
       loop 
         p2 := position('''' in str);
         p3 := position('''''' in str);
         exit when p2=0;
         if p3>0 and p2=p3 then
           o.oracle_script := substring(o.oracle_script from 1 for p1+p3-1)||'"'||substring(o.oracle_script from p1+p3+2);
           str := substring(str from 1 for p3-1)||'"'||substring(str from p3+2);
           continue;
         end if;
         str :=substring(str from 1 for p2-1);
         str := replace(str,'''''','"');
         o.oracle_script := substring(o.oracle_script from 1 for p1+p2-1)||'~'||substring(o.oracle_script from p1+p2+1);
         o.oracle_script := replace(o.oracle_script,'~'||str||'~','');
       end loop;
     end loop;
     --
     --     ,          
     for p in (select num,value from o2p_f_l2t(o.oracle_script,'begin')) loop
      if lower(p.value) ~ '.*\s+procedure\s+(.*)\s+is\s+' then
       --    
       --select ltrim(value,'_') into pname from o2p_f_l2t(lower(p.value),'procedure') where num=2;
       select substring(p.value,'.*\s+procedure\s+(.*)\s+is\s+') into pname;
       if pname like '%(%)' then
         --    ,  
         pname := regexp_replace(pname,'\(.+\)','');
       end if;
      elsif p.value ~ '.*\s+function\s+(.*)\s+return.*' then
       --    
       --select ltrim(value,'_') into pname from o2p_f_l2t(lower(p.value),'function') where num=2;
       select substring(p.value,'.*\s+function\s+(.*)\s+return.*') into pname;
       if pname like '%(%)' then
         --    ,  
         pname := regexp_replace(pname,'\(.+\)','');
       end if;
      else
       --    ,    pl/sql-
       continue;
      end if;
      select value into pname from o2p_f_l2t(ltrim(lower(pname),' '),'(') where num=1;
      select value into pname from o2p_f_l2t(lower(pname),' ') where num=1;
      select value into pname from o2p_f_l2t(lower(pname),chr(10)) where num=1;
      i := i+1;
      cmd := coalesce(cmd,'')||chr(10)||
      ''||chr(10)||
      'SQL:insert into o2p_t_file (id,filename,path,filedata,acsessionot4file_id,num)'||chr(10)||
      'values(nextval(''o2p_q_file''),'''||pname||'_package.sql'','||chr(10)||
      '''{ApplicationProperty:TmpDir}'||P_PROJECT_CODE||
      '/schema/'||lower(r.ot_code)||'s/'||lower(o.name)||''','
      ||chr(10)||'''-'','||r.id||','||i||');commit;';
     end loop;
    end loop;
   --
   end if;
  end loop;
  return trim(leading ' '||chr(10) from cmd);
 --
 elsif p_stage_name='LOAD_FILEDATA' then
  select name into pname from o2p_t_project where code=P_PROJECT_CODE;
  cmd :='PLPGSQL:(LUI$)declare prms text;'||chr(10)||
  'begin'||chr(10)||
  ' select coalesce(min(''Y''),''N'') into prms from lui_t_task where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILE_'||P_PROJECT_CODE||''';'||chr(10)||
  ' if prms=''N'' then'||chr(10)||
  '  perform lui_f_create_async_task ('||chr(10)||
  '  ''LUI4ORA2PG'','||chr(10)||
  '  ''O2P_T_LOADFILE'','||chr(10)||
  '  ''DEFAULT'','||chr(10)||
  '  ''{ApplicationProperty:dbUser}'','||chr(10)||
  '  ''{ApplicationProperty:dbPassword}'','||chr(10)||
  '  ''{ApplicationProperty:dbURL}'','||chr(10)||
  '  ''{ApplicationProperty:dbSCHEMA}'','||chr(10)||
  '  ''O2P_T_LOADFILE_'||P_PROJECT_CODE||''', --  '||chr(10)||
  '  ''    "'||pname||'"'', --  '||chr(10)||
  '  ''LUI4ORA2PG'''||chr(10)||
  '  );'||chr(10)||
  ' end if;'||chr(10)||
  ' select params into prms from lui_t_task'||chr(10)||
  ' where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILE_'||P_PROJECT_CODE||''' and status=''DISABLE'';'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_ACSESSION_ID'','''||P_ACSESSION_ID||''');'||chr(10)||
  ' update lui_v_task set params=prms where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILE_'||P_PROJECT_CODE||''' and status=''DISABLE'';'||chr(10)||
  ' perform lui_r_start_async_task(''LUI4ORA2PG''::lui_d_code32,''O2P_T_LOADFILE_'||P_PROJECT_CODE||'''::lui_d_code32,'||chr(10)||
  ' ''ONCE''::lui_d_code32,''1''::lui_d_code32,''00:00:00''::lui_d_code32,''''::lui_d_code32);'||chr(10)||
  'end;'||chr(10)||
  ''||chr(10)||
  'SQL:(LUI$)commit;';
  return cmd;
 --
 elsif p_stage_name='LOAD_FILEDATA_PKG' then
  select name into pname from o2p_t_project where code=P_PROJECT_CODE;
  select oschema4acsession_name into oschema from o2p_t_acsession where id=P_ACSESSION_ID;
  cmd :='PLPGSQL:(LUI$)declare prms text;'||chr(10)||
  'begin'||chr(10)||
  ' select coalesce(min(''Y''),''N'') into prms from lui_t_task where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_PKG_'||P_PROJECT_CODE||''';'||chr(10)||
  ' if prms=''N'' then'||chr(10)||
  '  perform lui_f_create_async_task ('||chr(10)||
  '  ''LUI4ORA2PG'','||chr(10)||
  '  ''O2P_T_LOADFILES_PKG'','||chr(10)||
  '  ''DEFAULT'','||chr(10)||
  '  ''{ApplicationProperty:dbUser}'','||chr(10)||
  '  ''{ApplicationProperty:dbPassword}'','||chr(10)||
  '  ''{ApplicationProperty:dbURL}'','||chr(10)||
  '  ''{ApplicationProperty:dbSCHEMA}'','||chr(10)||
  '  ''O2P_T_LOADFILES_PKG_'||P_PROJECT_CODE||''', --  '||chr(10)||
  '  '' ddl-     "'||pname||'"'', --  '||chr(10)||
  '  ''LUI4ORA2PG'''||chr(10)||
  '  );'||chr(10)||
  ' end if;'||chr(10)||
  ' select params into prms from lui_t_task where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_PKG_'||P_PROJECT_CODE||''' and status=''DISABLE'';'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_ACSESSION_ID'','''||P_ACSESSION_ID||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_PROJECT_CODE'','''||P_PROJECT_CODE||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_ORACLE_SCHEMA'','''||oschema||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_APP_TMPDIR'',''{ApplicationProperty:TmpDir}'');'||chr(10)||
  ' update lui_v_task set params=prms where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_PKG_'||P_PROJECT_CODE||''' and status=''DISABLE'';'||chr(10)||
  ' perform lui_r_start_async_task(''LUI4ORA2PG''::lui_d_code32,''O2P_T_LOADFILES_PKG_'||P_PROJECT_CODE||'''::lui_d_code32,'||chr(10)||
  ' ''ONCE''::lui_d_code32,''1''::lui_d_code32,''00:00:00''::lui_d_code32,''''::lui_d_code32);'||chr(10)||
  'end;'||chr(10)||
  ''||chr(10)||
  'SQL:(LUI$)commit;';
  return cmd;
 --
 elsif p_stage_name='LOAD_FILEDATA_FNC' then
  select name into pname from o2p_t_project where code=P_PROJECT_CODE;
  select oschema4acsession_name into oschema from o2p_t_acsession where id=P_ACSESSION_ID;
  cmd :='PLPGSQL:(LUI$)declare prms text;'||chr(10)||
  'begin'||chr(10)||
  ' select coalesce(min(''Y''),''N'') into prms from lui_t_task where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_FNC_'||P_PROJECT_CODE||''';'||chr(10)||
  ' if prms=''N'' then'||chr(10)||
  '  perform lui_f_create_async_task ('||chr(10)||
  '  ''LUI4ORA2PG'','||chr(10)||
  '  ''O2P_T_LOADFILES_FNC'','||chr(10)||
  '  ''DEFAULT'','||chr(10)||
  '  ''{ApplicationProperty:dbUser}'','||chr(10)||
  '  ''{ApplicationProperty:dbPassword}'','||chr(10)||
  '  ''{ApplicationProperty:dbURL}'','||chr(10)||
  '  ''{ApplicationProperty:dbSCHEMA}'','||chr(10)||
  '  ''O2P_T_LOADFILES_FNC_'||P_PROJECT_CODE||''', --  '||chr(10)||
  '  '' ddl-     "'||pname||'"'', --  '||chr(10)||
  '  ''LUI4ORA2PG'''||chr(10)||
  '  );'||chr(10)||
  ' end if;'||chr(10)||
  ' select params into prms from lui_t_task where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_FNC_'||P_PROJECT_CODE||''' and status=''DISABLE'';'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_ACSESSION_ID'','''||P_ACSESSION_ID||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_PROJECT_CODE'','''||P_PROJECT_CODE||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_ORACLE_SCHEMA'','''||oschema||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_APP_TMPDIR'',''{ApplicationProperty:TmpDir}'');'||chr(10)||
  ' update lui_v_task set params=prms where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_FNC_'||P_PROJECT_CODE||''' and status=''DISABLE'';'||chr(10)||
  ' perform lui_r_start_async_task(''LUI4ORA2PG''::lui_d_code32,''O2P_T_LOADFILES_FNC_'||P_PROJECT_CODE||'''::lui_d_code32,'||chr(10)||
  ' ''ONCE''::lui_d_code32,''1''::lui_d_code32,''00:00:00''::lui_d_code32,''''::lui_d_code32);'||chr(10)||
  'end;'||chr(10)||
  ''||chr(10)||
  'SQL:(LUI$)commit;';
  return cmd;
--
 elsif p_stage_name='LOAD_FILEDATA_TRG' then
  select name into pname from o2p_t_project where code=P_PROJECT_CODE;
  select oschema4acsession_name into oschema from o2p_t_acsession where id=P_ACSESSION_ID;
  cmd :='PLPGSQL:(LUI$)declare prms text;'||chr(10)||
  'begin'||chr(10)||
  ' select coalesce(min(''Y''),''N'') into prms from lui_t_task where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_TRG_'||P_PROJECT_CODE||''';'||chr(10)||
  ' if prms=''N'' then'||chr(10)||
  '  perform lui_f_create_async_task ('||chr(10)||
  '  ''LUI4ORA2PG'','||chr(10)||
  '  ''O2P_T_LOADFILES_TRG'','||chr(10)||
  '  ''DEFAULT'','||chr(10)||
  '  ''{ApplicationProperty:dbUser}'','||chr(10)||
  '  ''{ApplicationProperty:dbPassword}'','||chr(10)||
  '  ''{ApplicationProperty:dbURL}'','||chr(10)||
  '  ''{ApplicationProperty:dbSCHEMA}'','||chr(10)||
  '  ''O2P_T_LOADFILES_TRG_'||P_PROJECT_CODE||''', --  '||chr(10)||
  '  '' ddl-    "'||pname||'"'', --  '||chr(10)||
  '  ''LUI4ORA2PG'''||chr(10)||
  '  );'||chr(10)||
  ' end if;'||chr(10)||
  ' select params into prms from lui_t_task where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_TRG_'||P_PROJECT_CODE||''' and status=''DISABLE'';'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_ACSESSION_ID'','''||P_ACSESSION_ID||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_PROJECT_CODE'','''||P_PROJECT_CODE||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_ORACLE_SCHEMA'','''||oschema||''');'||chr(10)||
  ' prms:=lui_f_collection(prms,''P_APP_TMPDIR'',''{ApplicationProperty:TmpDir}'');'||chr(10)||
  ' update lui_v_task set params=prms where app_code=''LUI4ORA2PG'' and code=''O2P_T_LOADFILES_TRG_'||P_PROJECT_CODE||''' and status=''DISABLE'';'||chr(10)||
  ' perform lui_r_start_async_task(''LUI4ORA2PG''::lui_d_code32,''O2P_T_LOADFILES_TRG_'||P_PROJECT_CODE||'''::lui_d_code32,'||chr(10)||
  '''ONCE''::lui_d_code32,''1''::lui_d_code32,''00:00:00''::lui_d_code32,''''::lui_d_code32);'||chr(10)||
  'end;'||chr(10)||
  ''||chr(10)||
  'SQL:(LUI$)commit;';
  return cmd;
  /* Check-  !
 elsif p_stage_name='CREATE_CHECK_CONSTRAINT' then
  select report_only into reponly from o2p_t_acsession where id=P_ACSESSION_ID;
  if reponly='Y' then return null; end if;
  select count(*) into i from o2p_t_acsession_ot where acsession4acot_id=P_ACSESSION_ID
  and ot_code='TABLE';
  if i=0 then return null; end if;
  cmd :='PLPGSQL:declare porec record;'||chr(10)||
  'pgoid numeric;'||chr(10)||
  'begin'||chr(10)||
  ' for porec in (select id,export_schema,name,oracle_script from o2p_t_project_object'||chr(10)||
  '  where motype_code=''CONSTRAINT'' and comment is not null)'||chr(10)||
  ' loop'||chr(10)||
  '  continue when porec.oracle_script is null;'||chr(10)||
  '  insert into o2p_t_object (id,postgres_script,ostatus4o_code,postgres_schema,'||chr(10)||
  '  acsession4o_id,name,pgtype4o_code) values '||chr(10)||
  ' (nextval(''o2p_q_object''),porec.oracle_script,''AUTO'',porec.export_schema,'||chr(10)||
  P_ACSESSION_ID||',porec.name,''CONSTRAINT'') returning id into pgoid;'||chr(10)||
  '  insert into o2p_t_object4projectobject(id,po4opo_id,o4opo_id)'||chr(10)||
  '  values(nextval(''o2p_q_object4projectobject''),porec.id,pgoid);'||chr(10)||
  ' end loop;'||chr(10)||
  'end;';
  return cmd;
  */
 end if;
 return null;
END;
$body$
LANGUAGE 'plpgsql'
VOLATILE
CALLED ON NULL INPUT
SECURITY INVOKER
PARALLEL UNSAFE
COST 100;

ALTER FUNCTION ora2pg_project.o2p_f_make_command (p_project_code text, p_acsession_id numeric, p_stage_name text, p_oracle_home text)
  OWNER TO ora2pg_project;