CREATE OR REPLACE FUNCTION ora2pg_project.o2p_f_make_command4restrict (
  p_project_code text,
  p_acsession_id integer,
  p_po_id integer
)
RETURNS text AS
$body$
DECLARE
  rtext text;
  vResTmp text;
  vPkgs text;
  whattodo text;
  i numeric;
  r record;
  bCheckStarted boolean := false;
  bCommentStarted boolean := false;
  bfncStarted boolean := false;
  bIsMultiLine boolean := false;
  bFirstFuncDeclared boolean := false;
  nCnt numeric := 0;
  porec o2p_t_project_object;
  rtypecur record;
  cmd text;
BEGIN
  select * into porec from o2p_t_project_object where id=p_po_id;
  if not found then return null; end if;
  cmd := null;
  for rtypecur in (select restriction_code from o2p_t_rf_motype2restriction where motype_code=porec.motype_code) loop
    rtext := null;
    bCheckStarted := false;
    bCommentStarted := false;
    bfncStarted := false;
    bIsMultiLine := false;
    bFirstFuncDeclared := false;
    --
    if rtypecur.restriction_code = 'BULK_COLLECT' then -- BULK COLLECT
      for r in (select num from o2p_f_l2t(porec.oracle_script,chr(10)) where lower(value) like '%bulk collect%') loop
        rtext := coalesce(rtext,'')||chr(10)||' '||r.num||';';
      end loop;
     --     
    elsif rtypecur.restriction_code = 'NESTED_FUNCTION' then --  
      if porec.motype_code='PACKAGE' then bCheckStarted := false; else bCheckStarted := true; end if;
      if porec.motype_code='TRIGGER' then bfncStarted := true; else bfncStarted := false; end if;
      nCnt := 0;
      for r in (select num,value from o2p_f_l2t(porec.oracle_script,chr(10))) loop
        if not bCheckStarted then
          if lower(r.value) like '% package body %' then bCheckStarted := true; end if;
          continue;
        end if;
        --  ,  bCheckStarted=true
        if ltrim(lower(r.value)) like 'function%' or ltrim(lower(r.value)) like 'procedure%' then
          if bFncStarted then
            nCnt := nCnt+1; rtext := coalesce(rtext,'')||chr(10)||' '||r.num||';';
          else
            nCnt := 0; bFncStarted := true;
          end if;
        end if;
        if ltrim(lower(r.value)) like 'begin%' then
          if nCnt > 0 then nCnt := nCnt-1; else bfncStarted := false; end if;
        end if;
      end loop;      
    --
    elsif rtypecur.restriction_code = 'DBMS_UTL' then -- SYS-
      vPkgs := null;
      for r in (select num,value from o2p_f_l2t(porec.oracle_script,chr(10))
                where lower(value) like '%dbms!_%.%' escape '!' or lower(value) like '%utl!_%.%' escape '!')
      loop
        vPkgs := o2p_f_find_pkgname4str(vPkgs,r.value,'UTL');
        vPkgs := o2p_f_find_pkgname4str(vPkgs,r.value,'DBMS');
        rtext := coalesce(rtext,'')||chr(10)||' '||r.num||';';
      end loop;
    --
    elsif rtypecur.restriction_code = 'CONNECT_BY' then -- Connect by
      for r in (select num from o2p_f_l2t(porec.oracle_script,chr(10)) where lower(value) like '%connect by%') loop
        rtext := coalesce(rtext,'')||chr(10)||' '||r.num||';';
      end loop;
    --
    elsif rtypecur.restriction_code = 'DECODE' then -- Decode
      for r in (select num from o2p_f_l2t(porec.oracle_script,chr(10)) where lower(value) like '%decode(%') loop
        rtext := coalesce(rtext,'')||chr(10)||' '||r.num||';';
      end loop;
    --
    elsif rtypecur.restriction_code = 'GLVAR_PKG_HEADER' then --   
      ncnt := 0;
      for r in (select num,value from o2p_f_l2t(porec.oracle_script,chr(10))) loop
        if ltrim(lower(r.value)) like '%package%' then ncnt := 1; end if;
        continue when ncnt=0;
        if ltrim(lower(r.value)) like '%package%'
        or ltrim(lower(r.value)) like '--%'
        or trim(lower(r.value)) = 'is %'
        or trim(lower(r.value)) = 'as %'
        or trim(r.value) is null
        then
          continue;
        end if;
        if ltrim(lower(r.value)) like 'function%'
        or ltrim(lower(r.value)) like 'procedure%'
        or ltrim(lower(r.value)) like '/*%' then
          if trim(lower(r.value)) not like '%*/%' then bCheckStarted := true; end if;
        end if;
        if ltrim(lower(r.value)) like '/*%' then bCommentStarted := true; end if;
        if ltrim(lower(r.value)) like '%;%' and ltrim(lower(r.value)) not like '%--%;%' then
          if bCheckStarted then
            bCheckStarted := false;
            continue;
          elsif ltrim(lower(r.value)) like 'end;%'
             or ltrim(lower(r.value)) like 'end %;%' then
             continue;
          end if;
        end if;
        if ltrim(lower(r.value)) like '*/%' then
          if bCommentStarted then bCommentStarted := false; end if;
          continue;
        end if;
        if not bCheckStarted and not bCommentStarted then
          rtext := coalesce(rtext,'')||chr(10)||' '||r.num||';';
        end if;
      end loop;
    --
    elsif rtypecur.restriction_code = 'GLVAR_PKG_BODY' then --   
      ncnt := 0;
      for r in (select num,value from o2p_f_l2t(porec.oracle_script,chr(10))) loop
        if ltrim(lower(r.value)) like '%package body%' then ncnt := 1; end if;
        continue when ncnt=0;
        if ltrim(lower(r.value)) like '%package body%'
        or ltrim(lower(r.value)) like '--%'
        or trim(lower(r.value)) = 'is %'
        or trim(lower(r.value)) = 'as %'
        or trim(r.value) is null then
          continue;
        end if;
        if ltrim(lower(r.value)) like '/*%' then
          if trim(lower(r.value)) not like '%*/%' then bCommentStarted := true; end if;
        end if;
        if ltrim(lower(r.value)) like 'function%'
        or ltrim(lower(r.value)) like 'procedure%' then
          exit;
        end if;
        if ltrim(lower(r.value)) like '*/%' then
          if bCommentStarted then bCommentStarted := false; end if;
          continue;
        end if;
        if not bCommentStarted then
          rtext := coalesce(rtext,'')||' '||r.num||';';
        end if;
      end loop;
    --
    elsif rtypecur.restriction_code = 'COMMENT_BETWEEN_PKGFUNC' then --    
      vResTmp := null; ncnt := 0; bFirstFuncDeclared := false; bIsMultiLine := false;
      for r in (select num,value from o2p_f_l2t(porec.oracle_script,chr(10))) loop
        if ltrim(lower(r.value)) like '%package body%' then ncnt := 1; end if;
        continue when ncnt=0; --   
        --
        if ltrim(lower(r.value)) like '%package body%'
        or trim(lower(r.value)) = 'is %'
        or trim(lower(r.value)) = 'as %'
        or trim(r.value) is null then
          continue; --    ,      /
        end if;
        --
        if bIsMultiLine then --      ...
          if trim(r.value) like '%*/' then            
            bIsMultiLine := false;
            continue; --   ,    
          elsif trim(r.value) like '%*/%' then            
            bIsMultiLine := false;
            --      ,      
          end if;
        end if;
        --
        if not bIsMultiLine then
          if trim(r.value) like '/*%' then
            --       ...
            if bFirstFuncDeclared then
              vResTmp := coalesce(vResTmp,'')||' '||r.num||';';
            end if;
            continue when trim(r.value) like '/*%*/'; --   ,   
            if trim(r.value) like '/*%*/%' then
              --      ,      
            else
              bIsMultiLine := true;
              continue;
            end if;
          end if;
        end if;
        --     ,      
        if trim(r.value) like '--%' then
          --    ...
          if bFirstFuncDeclared then
            vResTmp := coalesce(vResTmp,'')||chr(10)||' '||r.num||';';
          end if;  
          continue;
        end if;
        --  ,       .
        --   /
        if not bFirstFuncDeclared then
          --    bFirstFuncDeclared (    )
          if upper(trim(r.value)) = 'PROCEDURE'
          or upper(trim(r.value)) = 'FUNCTION'
          or upper(trim(r.value)) like 'PROCEDURE %'
          or upper(trim(r.value)) like 'FUNCTION %'          
          then
            bFirstFuncDeclared := true;
            vResTmp := null; --     
          end if;   
        end if;
        --       ...
        if vResTmp is not null then
          --     /,
          --   vResTmp  
          --      
          if upper(trim(r.value)) = 'PROCEDURE'
            or upper(trim(r.value)) = 'FUNCTION'
            or upper(trim(r.value)) like 'PROCEDURE %'
            or upper(trim(r.value)) like 'FUNCTION %' 
          then
            --       vResTmp    vRes
            rtext := coalesce(rtext,'')||vResTmp;
          end if;
        end if;
      end loop;
    --
    elsif rtypecur.restriction_code = 'COMPOUND_TRIGGER' then --  
      select num into i from o2p_f_l2t(porec.oracle_script,chr(10)) where lower(value) like '%compound trigger%';
      if found then rtext := ' '||i||';'; end if;
    --  
    elsif rtypecur.restriction_code = 'UNKNOWN_SOURCE_TYPE' then --     
      rtext := substring(porec.comment,
      (position('(' in porec.comment)+1)::integer,
      (position(')' in porec.comment)-1)::integer-position('(' in porec.comment));
      if rtext='UNKNOWN' then
        rtext := substring(porec.comment,
        position('@' in porec.comment),
        (position('(' in porec.comment)-1)::integer-(position('@' in porec.comment)-1)::integer);
      end if;
      --
    elsif rtypecur.restriction_code = 'SOURCE_ISNOT_TABLE' then --       
      rtext := substring(porec.comment,
      (position('(' in porec.comment)+1)::integer,
      (position(')' in porec.comment)-1)::integer-position('(' in porec.comment));
      if rtext in ('TABLE','VIEW','MVIEW') then rtext := null; end if;
    --  
    elsif rtypecur.restriction_code = 'OBJECT_TYPE' then --   
      if porec.comment = 'OBJECT' then rtext := porec.comment; end if;
    --  
    elsif rtypecur.restriction_code = 'TEMPORARY_TABLE' then --  
      if porec.comment like 'TEMPORARY%' then rtext := 'TEMPORARY_TABLE'; end if;
    --  
    elsif rtypecur.restriction_code = 'ROLE_WITH_PASSWORD'  then --   
      if porec.comment like '%PASSWORD_REQUIRED%' then rtext := 'PASSWORD_REQUIRED'; end if;
    --
    elsif rtypecur.restriction_code = 'DBA_PRIVS4ROLE' then
     rtext := 
     '{NLS:RUS:,      ;'||
     'ENG:User in Oracle connection for role auto-migration;}';
     --
     elsif rtypecur.restriction_code = 'PRIVS4ROLE' then
       rtext := '{NLS:RUS: Oracle,   ;'||
       'ENG:Oracle schema in auto-migration session;}';
    elsif rtypecur.restriction_code = 'USER_WITH_PASSWORD' then
      if rtext like '%PASSWORD_REQUIRED%' then rtext := 'PASSWORD_REQUIRED'; end if;
    --
    elsif rtypecur.restriction_code = 'DBA_PRIVS4USER' then
      rtext := '{NLS:RUS:,      ;'||
      'ENG:User in Oracle connection for user auto-migration;}';
    --
    elsif rtypecur.restriction_code ='PRIVS4USER' then
      rtext := '{NLS:RUS: Oracle,   ;'||
      'ENG:Oracle schema in auto-migration session;}';
    end if;
    rtext := trim(leading chr(10) from rtext);
    if rtext is not null then
      select recommendations into whattodo from o2p_t_rf_restriction_type where code=rtypecur.restriction_code;
      cmd := coalesce(cmd,'')||chr(10)||chr(10)||
      'SQL:insert into o2p_t_object_restriction'||chr(10)||
      '(id, rtype4orestriction_code, project4orestriction_code, po4orestriction_id, acsession4orestriction_id, attention_to, todo, notes)'||chr(10)||
      'values (nextval(''o2p_q_object_restriction''), '''||rtypecur.restriction_code||''', '''||p_PROJECT_CODE||
      ''', '||porec.id||', '||p_ACSESSION_ID||', '||quote_literal(rtext)||', '||quote_literal(whattodo)||', '''');';
    end if;
  end loop;
  return trim(leading chr(10) from cmd);
END;
$body$
LANGUAGE 'plpgsql'
VOLATILE
CALLED ON NULL INPUT
SECURITY INVOKER
PARALLEL UNSAFE
COST 100;

ALTER FUNCTION ora2pg_project.o2p_f_make_command4restrict (p_project_code text, p_acsession_id integer, p_po_id integer)
  OWNER TO ora2pg_project;