CREATE OR REPLACE FUNCTION ora2pg_project.o2p_f_make_objlist_4_config (
  p_acsession_id numeric,
  p_usage_type text = 'ALLOW'::text
)
RETURNS text AS
$body$
DECLARE
  v_project_code text;
  v_export_schema text;
  mobjlist text := '';
  objlist text := '';
  motype record;
  obj record;
  i numeric;
BEGIN
  select project4acsession_code, oschema4acsession_name
  into v_project_code,v_export_schema from o2p_t_acsession where id = p_acsession_id;
  if p_usage_type = 'ALLOW' then
    for motype in (select distinct motype_code code
                     from o2p_t_project_object
	  			    where project4obj_code = v_project_code
			          and coalesce(export_schema,v_export_schema) = v_export_schema
				    order by motype_code)
    loop
      continue when motype.code in ('INDEX','FKEY','CONSTRAINT','USER','ROLE');
	  select count(*) into i from o2p_t_acsession_ot where acsession4acot_id = p_acsession_id and ot_code = motype.code;
	  if i = 0 then continue; end if;
	   
      if mobjlist <> '' then mobjlist := mobjlist||';'; end if;
	  mobjlist := mobjlist||motype.code||'[';

      objlist := '';
	  for obj in (select * from o2p_t_project_object t1
                   where project4obj_code = v_project_code
			         and coalesce(export_schema,v_export_schema) = v_export_schema
				     and motype_code = motype.code
                     and not exists 
					      (select 1 from o2p_t_object4projectobject t3
                           join o2p_t_object t2 on t2.id = t3.o4opo_id
					        where t3.po4opo_id=t1.id
						      and exists 
							      (select 1 from o2p_t_object 
								    where postgres_schema = t2.postgres_schema
							          and name = t2.name 
									  and ostatus4o_code in ('READY','CANCELLED')))

		   	       order by name)
      loop
	    if objlist <> '' then objlist := objlist||' '; end if;
	    objlist := objlist||obj.name;
      end loop;

	  mobjlist := mobjlist||objlist||']';
    end loop;

  elsif p_usage_type = 'EXCLUDE' then
    for motype in (
     select * from o2p_t_rf_object_type
	 where code not in
	  (select distinct motype_code code from o2p_t_project_object
	   where project4obj_code = v_project_code
	   and coalesce(export_schema,v_export_schema)=v_export_schema
      )
	  or code not in
       (
       select ot_code from o2p_t_acsession_ot where acsession4acot_id = p_acsession_id)
       )
	loop
      continue when motype.code in ('INDEX','FKEY','CONSTRAINT','USER','ROLE');
      if motype.code='TABLE' then
       select count(*) into i from o2p_t_acsession_ot
       where acsession4acot_id = p_acsession_id and ot_code in ('DIRECTORY','TABLESPACE','USER','ROLE','TRIGGER');
       continue when i>0;
      end if;
	  if mobjlist <> '' then mobjlist := mobjlist||';'; end if;
	  mobjlist := mobjlist||motype.code||'[*]';
	end loop;
  end if;

  return mobjlist;
END;
$body$
LANGUAGE 'plpgsql'
VOLATILE
CALLED ON NULL INPUT
SECURITY INVOKER
PARALLEL UNSAFE
COST 100;

ALTER FUNCTION ora2pg_project.o2p_f_make_objlist_4_config (p_acsession_id numeric, p_usage_type text)
  OWNER TO ora2pg_project;