CREATE OR REPLACE FUNCTION ora2pg_project.o2p_r_convertlog (
  p_acsession_id ora2pg_project.o2p_d_id
)
RETURNS void AS
$body$
DECLARE
  l record;
  acs o2p_t_acsession;
  problem boolean;
  problemtext text;
  poid integer;
  potype text;
begin
  select * into acs from o2p_t_acsession where id=p_acsession_id;
  if acs.errtext is null then return; end if;
  acs.errtext := replace(acs.errtext,chr(13),chr(10));
  if acs.report_only='N' then
    problem := false; problemtext := null;
    for l in (select num,value from o2p_f_l2t(acs.errtext,chr(10)) t) loop
      if l.value like '% generating %' or l.value like '% exporting %' then
        if problem then
          select motype_code into potype from o2p_t_project_object where id=poid;
          if problemtext like '%FATAL%' then
            update o2p_t_po2acsession set
              problem_text=problemtext,
              rescode4po_code='ERROR'
            where acsession4po_id=p_acsession_id and
              exists (select 1 from o2p_t_project_object t2
              where t2.project4obj_code=acs.project4acsession_code
              and t2.motype_code=potype and t2.id=po4acsession_id)
              and rescode4po_code is null;
          elsif problemtext like '%WARNING%' then
            update o2p_t_po2acsession set
              problem_text=problemtext,
              rescode4po_code='WARNING'
            where acsession4po_id=p_acsession_id
              and po4acsession_id=poid;
          else
            update o2p_t_po2acsession set
              problem_text=problemtext,
              rescode4po_code='ERROR'
            where acsession4po_id=p_acsession_id
              and po4acsession_id=poid;
          end if;
          problem := false; problemtext := null;
        elsif poid is not null then
          update o2p_t_po2acsession set
             problem_text=null,
              rescode4po_code='OK'
            where acsession4po_id=p_acsession_id
              and po4acsession_id=poid;
        end if;      
        select po4acsession_id into poid
        from o2p_t_po2acsession t1 where acsession4po_id=p_acsession_id and
        exists (select 1 from o2p_t_project_object t2 where t2.project4obj_code=acs.project4acsession_code
        and coalesce(export_schema,coalesce(acs.oschema4acsession_name,'!'))=coalesce(acs.oschema4acsession_name,'!')
        and
        case
          when l.value like '% generating %' then lower(trim(l.value))||'!' like '%generating '||lower(t2.name)||'!'
          when l.value like '% exporting %' then lower(trim(l.value))||'!' like '%exporting '||lower(t2.name)||'!'
        end
        and t1.po4acsession_id=t2.id);
        if not found then
          poid := null; problem := false; problemtext := null; --       
        end if;
        continue;
      --
      elsif l.value like '% end of %' and poid is not null then
        update o2p_t_po2acsession set
          problem_text=null,
          rescode4po_code='OK'
        where acsession4po_id=p_acsession_id
          and po4acsession_id=poid;
        poid := null; problem := false; problemtext := null;
        continue;
      elsif l.value like '% scanning %' then continue;
      elsif poid is not null then
        problem := true;
        problemtext := coalesce(problemtext,'')||l.value;
      else
        continue;
      end if;
    end loop;
    --
    if problem then
      select motype_code into potype from o2p_t_project_object where id=poid;
      if problemtext like '%FATAL%' then
        update o2p_t_po2acsession set
          problem_text=problemtext,
          rescode4po_code='ERROR'
        where t1.acsession4po_id=p_acsession_id and
          exists (select 1 from o2p_t_project_object t2
          where t2.project4obj_code=acs.project4acsession_code
          and t2.motype_code=potype and t2.id=po4acsession_id)
          and rescode4po_code is null;
      elsif problemtext like '%WARNING%' then
        update o2p_t_po2acsession set
          problem_text=problemtext,
          rescode4po_code='WARNING'
        where acsession4po_id=p_acsession_id
          and po4acsession_id=poid;
      else
        update o2p_t_po2acsession set
          problem_text=problemtext,
          rescode4po_code='ERROR'
        where acsession4po_id=p_acsession_id
         and po4acsession_id=poid;
      end if;
    else
      update o2p_t_po2acsession set
        problem_text=null,
        rescode4po_code='OK'
      where acsession4po_id=p_acsession_id
        and po4acsession_id=poid;
    end if;
  
    update o2p_t_po2acsession set
      problem_text='skipped',
      rescode4po_code='WARNING'
    where acsession4po_id=p_acsession_id and rescode4po_code is null;
  -- REPORT_ONLY
  else
    update o2p_t_po2acsession set
      problem_text=null,
      rescode4po_code='OK'
    where acsession4po_id=p_acsession_id;
  end if;
END;
$body$
LANGUAGE 'plpgsql'
VOLATILE
CALLED ON NULL INPUT
SECURITY INVOKER
PARALLEL UNSAFE
COST 100;

ALTER FUNCTION ora2pg_project.o2p_r_convertlog (p_acsession_id ora2pg_project.o2p_d_id)
  OWNER TO ora2pg_project;