﻿CREATE OR REPLACE FUNCTION ora2pg_project.o2p_r_delete_project (
  p_project_code text
)
RETURNS void AS
$body$
declare
 r record;
 d record;
BEGIN
  -- 1. Удаление параметров проекта
  delete from o2p_t_parameter_value where project4parval_code = p_project_code;
  -- 2. Удаление сведений о нарушениях ограничений миграции для объектов проекта
  delete from o2p_t_object_restriction where project4orestriction_code = p_project_code;
  -- 3. Удаление данных о файлах, полученных при выполнении автоматических действий по миграции проекта
  for r in (select fl.*
              from ora2pg_project.o2p_t_file fl
              left join ora2pg_project.o2p_t_acsession_ot aot on aot.id = fl.acsessionot4file_id
              left join ora2pg_project.o2p_t_acsession acs1 on acs1.id = aot.acsession4acot_id
              left join ora2pg_project.o2p_t_acsession_object ao on ao.id = fl.acso4file_id
              left join ora2pg_project.o2p_t_acsession acs2 on acs2.id = ao.acsession4acso_id
        where coalesce(acs1.project4acsession_code,'') = p_project_code
           or coalesce(acs2.project4acsession_code,'') = p_project_code)
  loop
    delete from o2p_t_file where id = r.id;
  end loop;
  -- 4. Удаление данных об объектах postgres в проекте
  for r in (select * from o2p_t_object where project4o_code = p_project_code)
  loop
    -- записи в журнале назначения ответственных за объект
	delete from o2p_t_responsible_log where o4resp_id = r.id;
	-- версии объекта
	delete from o2p_t_revision where o4rev_id = r.id;
	-- записи в таблице больших текстов
	update o2p_t_object set pgscript_id = null where id = r.id;
	delete from o2p_t_long_text where id = r.pgscript_id;
	-- записи об участии объекта в запусках автомиграций
	delete from o2p_t_acsession_object where o4acso_id = r.id;
	-- связь с объектом проекта
	delete from o2p_t_object4projectobject where o4opo_id = r.id;
	-- запись об объекте
	delete from o2p_t_object where id = r.id;
  end loop;
  -- 5. Удаление этапов миграции в проекте
  for r in (select * from o2p_t_step where project4step_code = p_project_code)
  loop
    -- записи в истории изменений состояний этапа миграции проекта
	delete from o2p_t_step_hist where step4hist_id = r.id;
	-- скрипты для этапа проекта
	for d in (select * from o2p_t_step_script where step_id = r.id)
	loop
	  update o2p_t_step_script set pgscript_id = null where id = d.id;
	  delete from o2p_t_long_text where id = d.pgscript_id;
	  delete from o2p_t_step_script where step_id = d.id;
	end loop;
	-- удаление ссылки на этап проекта в данных о сессиях автомиграции
	update o2p_t_acsession set step4acsession_id = null where step4acsession_id = r.id;
	-- запись об этапе проекта
	delete from o2p_t_step where id = r.id;
  end loop;
  -- 6. Удаление объектов проекта
  for r in (select * from o2p_t_project_object where project4obj_code = p_project_code)
  loop
    -- записи в журнале назначения ответственных за объект
	delete from o2p_t_poresponsible_log where po4poresp_id = r.id;
	-- версии объекта
	delete from o2p_t_porevision where po4porev_id = r.id;
	-- пользовательские настройки столбцов мигрируемых таблиц
	delete from o2p_t_tab_column where po4tabcol_id = r.id;
    -- удаление ссылки на версию ораклового ddl-скрипта для объекта проекта в данных о самом объекте проекта
	update o2p_t_project_object set oraddl4po_id = null where id = r.id;
	-- версии оракловых ddl-скриптов для объектов проекта
	delete from o2p_t_oracle_ddl where po4oraddl_id = r.id;
	-- записи об участии объекта проекта в запусках автомиграций
	delete from o2p_t_po2acsession where po4acsession_id = r.id;
	-- запись об объекте проекта
	delete from o2p_t_project_object where id = r.id;
  end loop;
  -- 7. Удаление данных о сессиях/запусках автоматических процессов для проекта миграции
  for r in (select * from o2p_t_acsession where project4acsession_code = p_project_code)
  loop
    -- задания для сессии
	delete from o2p_t_acsession_task where acsession4task_id = r.id;
	-- типы объектов проекта для сессии
	delete from o2p_t_acsession_ot where acsession4acot_id = r.id;
	-- запись о сессии
	delete from o2p_t_acsession where id = r.id;
  end loop;
  -- 8. Удаление данных об участниках проекта и соединениях. Удаляются записи только об участии пользователей в проекте. Данные о самих пользователях остаются в системе.
  for r in (select * from o2p_t_user_in_project where project4usr_code = p_project_code)
  loop
    -- соединения oracle
	delete from o2p_t_oracle_connection where user_in_project_id = r.id;
	-- соединения postgres
	delete from o2p_t_postgres_connection where user_in_project_id = r.id;
	-- запись об участии в проекте
	delete from o2p_t_user_in_project where id = r.id;
  end loop;
  -- 9. Удаление записи о проекте
  delete from o2p_t_project where code = p_project_code;
END;
$body$
LANGUAGE 'plpgsql'
VOLATILE
CALLED ON NULL INPUT
SECURITY INVOKER
PARALLEL UNSAFE
COST 100;

ALTER FUNCTION ora2pg_project.o2p_r_delete_project (p_project_code text)
  OWNER TO ora2pg_project;