CREATE OR REPLACE FUNCTION ora2pg_project.o2p_r_refresh_rights (
  p_username ora2pg_project.o2p_d_username,
  p_admin_option ora2pg_project.o2p_d_ny = 'N'::character varying,
  p_mode ora2pg_project.o2p_d_text = 'GRANT'::text
)
RETURNS void AS
$body$
declare
 n o2p_d_id;
 rec record;
 oname o2p_d_text;
 adm o2p_d_ny := coalesce(nullif(p_admin_option,''),'N');
 m o2p_d_text := coalesce(nullif(p_mode,''),'GRANT');
BEGIN
 if nullif(p_username,'') is null then return; end if;

 select o2p_f_owner() into oname;
 
 if m='GRANT' then
 
   if adm='Y' then
      execute 'alter role '||p_username||' createrole';
   end if;
 
   execute 'grant usage on schema '||oname||' to '||p_username||case when adm='Y' then ' WITH GRANT OPTION' else '' end;
   execute 'grant lui_common to '||p_username||case when adm='Y' then ' WITH ADMIN OPTION' else '' end;   

   --     
   for rec in (select domain_name from information_schema.domains where domain_schema=oname) loop
    execute 'grant usage on domain '||oname||'.'||rec.domain_name||' to '||p_username||case when adm='Y' then ' WITH GRANT OPTION' else '' end;
   end loop;
 
   --   sequence
   execute 'grant usage on all SEQUENCES in schema '||oname||' to '||p_username||case when adm='Y' then ' WITH GRANT OPTION' else '' end;
  
   --       
   execute 'grant execute on all functions in schema '||oname||' to '||p_username||case when adm='Y' then ' WITH GRANT OPTION' else '' end;
 
   --     
   execute 'grant select,insert,update,delete on all tables in schema '||oname||' to '||p_username||case when adm='Y' then ' WITH GRANT OPTION' else '' end;
 
 else
   if o2p_f_isitme(p_username) then return; end if; --       !
 
   if adm='Y' then
      execute 'alter role '||p_username||' nocreaterole';
   end if;

   execute 'revoke usage on schema '||oname||' from '||p_username;
   execute 'revoke lui_common from '||p_username;

   --     
   for rec in (select domain_name from information_schema.domains where domain_schema=oname) loop
    execute 'revoke usage on domain '||oname||'.'||rec.domain_name||' from '||p_username;
   end loop;
 
   --   sequence
   execute 'revoke usage on all SEQUENCES in schema '||oname||' from '||p_username;
  
   --       
   execute 'revoke execute on all functions in schema '||oname||' from '||p_username;
 
   --     
   execute 'revoke select,insert,update,delete on all tables in schema '||oname||' from '||p_username;
   
 end if;
END;
$body$
LANGUAGE 'plpgsql'
VOLATILE
CALLED ON NULL INPUT
SECURITY DEFINER
PARALLEL UNSAFE
COST 100;

ALTER FUNCTION ora2pg_project.o2p_r_refresh_rights (p_username ora2pg_project.o2p_d_username, p_admin_option ora2pg_project.o2p_d_ny, p_mode ora2pg_project.o2p_d_text)
  OWNER TO ora2pg_project;